@@ -1,6 +1,6 @@
 package Job::Machine;
 BEGIN {
-  $Job::Machine::VERSION = '0.14';
+  $Job::Machine::VERSION = '0.15';
 }
 
 1;
@@ -14,13 +14,13 @@ Job::Machine
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
 The Client:
 
-  my $client = Job::Machine::Client->new(jobclass => 'job.task');
+  my $client = Job::Machine::Client->new(queue => 'job.task');
   my $id = $client->send({foo => 'bar'});
 
 The Worker is a subclass
@@ -34,7 +34,7 @@ The Worker is a subclass
 
 and then use the worker
 
-  my $worker = Worker->new(jobclass => 'job.task');
+  my $worker = Worker->new(queue => 'job.task');
   $worker->receive;
 
 Back at the Client:
@@ -45,11 +45,39 @@ Back at the Client:
 
 =head1 DESCRIPTION
 
-A small, but versatile and efficient system for sending jobs to a message queue
-and communicating answers back to the sender.
+A small, but versatile system for sending jobs to a message queue and, if necessary,
+communicating answers back to the sender.
 
 Job::Machine uses LISTEN / NOTIFY from PostgreSQL to send signals between
-workers and clients
+clients and workers. This ensures very efficient message passing, giving any
+worker that is awake the chance to start working immediately.
+
+=head2 Database Connection
+
+Both client and worker accepts a Database Handle (dbh), or a Data Source Name (dsn).
+
+From scratch:
+
+  my $client = Job::Machine::Client->new(
+    dsn => 'dbi:Pg:dbname=jobqueue',
+    queue => 'my.queue',
+  );
+
+Hot Handle:
+
+  my $dbh = $self->existing_dbh;
+  my $client = Job::Machine::Client->new(
+    dbh => $dbh,
+    queue => 'my.queue',
+  );
+
+=head2 Queue
+
+Normally the queue name is passed as a parameter to new, but it can be overriden
+for any method call.
+
+The queue can be named anything PostgreSQL accepts. A good idea is to maintain a
+hierarchical structure. e.g. I<gl.accounting> or I<message.email>.
 
 =head1 NAME
 
