@@ -1,6 +1,6 @@
 package Job::Machine::Base;
 BEGIN {
-  $Job::Machine::Base::VERSION = '0.14';
+  $Job::Machine::Base::VERSION = '0.15';
 }
 
 use strict;
@@ -48,7 +48,7 @@ Job::Machine::Base
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 NAME
 
@@ -60,7 +60,7 @@ Job::Machine::Base - Base class both for Client and Worker Classes
 
   my $client = Job::Machine::Base->new(
 	  dbh   => $dbh,
-	  jobclass => 'queue',
+	  queue => 'queue',
 
   );
 
@@ -73,7 +73,7 @@ Arguments:
 Either provide an already warm database handle, or give a new array to tell how
 to open a database.
 
- jobclass is the channel to the worker.
+ queue is the channel to the worker.
  timeout is how long to wait for notifications before doing a housekeeping loop.
  Default is 5 minutes.
 
